@@ -1736,6 +1736,7 @@ app.controller('APIDeployerDeploymentSettingsController', function($scope, $q, T
                         $scope.inlineContainerConfig.properties = infraStatus.infraBasicInfo.k8sProperties;
                         $scope.inlineContainerConfig.baseImage = infraStatus.infraBasicInfo.baseImageTag;
                         $scope.inlineContainerConfig.repositoryURL = infraStatus.infraBasicInfo.registryHost;
+                        $scope.inlineContainerConfig.pullRepositoryURL = infraStatus.infraBasicInfo.pullRegistryHost;
                         $scope.inlineContainerConfig.prePushMode = infraStatus.infraBasicInfo.prePushMode;
                         $scope.inlineContainerConfig.prePushScript = infraStatus.infraBasicInfo.prePushScript;
                     } else {
@@ -1787,23 +1788,30 @@ app.controller('APIDeployerDeploymentSettingsController', function($scope, $q, T
 
                 $scope.endpointsPerPackage = APIDeployerDeploymentUtils.getEndpointsPerPackage($scope.lightStatus);
 
-                if (APIDeploymentInfraHelper.isFullyManagedInfra(infraType)) {
-                    $scope.endpoints = $scope.endpointsPerPackage[$scope.deploymentSettings.generationsMapping.generation];
-                    if (infraType === 'DATABRICKS') {
-                        $scope.compatibleEndpoints = $scope.endpoints.filter(e => $scope.isEndpointCompatibleWithDeployAnywhereDatabricks(e.type));
-                    } else {
-                        $scope.compatibleEndpoints = $scope.endpoints.filter(e => $scope.isEndpointCompatibleWithDeployAnywhere(e.type));
-                    }
-
-                    $scope.isCurrentEndpointIncompatible = false;
-                    if (!!($scope.deploymentSettings.endpointId) && !$scope.compatibleEndpoints.find(e => e.id === $scope.deploymentSettings.endpointId)) {
-                        $scope.isCurrentEndpointIncompatible = true;
-                    }
-                }
+                $scope.refreshEndpoints(infraType);
             })
             .error(setErrorInScope.bind($scope));
     });
 
+    $scope.refreshEndpoints = function (infraType) {
+        if (APIDeploymentInfraHelper.isFullyManagedInfra(infraType)) {
+            $scope.endpoints = $scope.endpointsPerPackage[$scope.deploymentSettings.generationsMapping.generation];
+            if (infraType === 'DATABRICKS') {
+                $scope.compatibleEndpoints = $scope.endpoints.filter(e => $scope.isEndpointCompatibleWithDeployAnywhereDatabricks(e.type));
+            } else {
+                $scope.compatibleEndpoints = $scope.endpoints.filter(e => $scope.isEndpointCompatibleWithDeployAnywhere(e.type));
+            }
+            $scope.refreshEndpointCompatibility();
+        }
+    }
+
+    $scope.refreshEndpointCompatibility = function() {
+        $scope.isCurrentEndpointIncompatible = false;
+        if (!!($scope.deploymentSettings.endpointId) && !$scope.compatibleEndpoints.find(e => e.id === $scope.deploymentSettings.endpointId)) {
+            $scope.isCurrentEndpointIncompatible = true;
+        }
+    }
+
     $scope.getAllTags = function () {
         var deferred = $q.defer();
         if (!$scope.hasOwnProperty("allProjectLevelTags")) {
