@@ -4,7 +4,7 @@
     const app = angular.module('dataiku.charts');
 
     // (!) This directive previously was in static/dataiku/js/simple_report/config_ui.js
-    app.directive('monoUaZone', function($parse, ChartFeatures, ChartLabels) {
+    app.directive('monoUaZone', function($parse, ChartFeatures, ChartLabels, Ng2MenuOrchestratorService) {
         return {
             templateUrl: '/static/dataiku/js/simple_report/directives/drag-drop/drop-zones/mono-ua-zone/mono-ua-zone.directive.html',
             scope: true,
@@ -14,6 +14,10 @@
                 $scope.acceptCallback = $parse(attrs.acceptCallback)($scope);
                 $scope.ChartFeatures = ChartFeatures;
                 $scope.ChartLabels = ChartLabels;
+
+                $scope.openMatMenu = function(menuIdx, event) {
+                    Ng2MenuOrchestratorService.triggerMenuOpen($scope.chartDefKey, menuIdx, event);
+                };
             }
         };
     });
