@@ -8,12 +8,12 @@ from dataiku.doctor import utils, step_constants
 from dataiku.core import intercom
 from dataiku.doctor.diagnostics import diagnostics
 from dataiku.doctor.diagnostics.diagnostics import DiagnosticType
-from dataiku.doctor.prediction.custom_scoring import get_custom_evaluation_metric
-from dataiku.doctor.timeseries.preparation.preprocessing import TimeseriesPreprocessing
+from dataiku.doctor.timeseries.preparation.preprocessing import TimeseriesPreprocessing, add_rolling_windows_for_scoring
 from dataiku.doctor.timeseries.models import TimeseriesForecastingAlgorithm
-from dataiku.doctor.timeseries.perf.model_perf import TimeseriesModelScorer, PER_TIMESERIES_METRICS, TIMESERIES_AGGREGATED_METRICS
+from dataiku.doctor.timeseries.perf.model_perf import TimeseriesModelScorer, PER_TIMESERIES_METRICS, \
+    TIMESERIES_AGGREGATED_METRICS, PER_FORECAST_DISTANCE_METRICS
 from dataiku.doctor.timeseries.preparation.resampling.utils import get_frequency
-from dataiku.doctor.timeseries.preparation.preprocessing import get_external_features
+from dataiku.doctor.timeseries.preparation.preprocessing import get_external_features, get_windows_list
 from dataiku.doctor.timeseries.score.scoring_handler import resample_for_scoring
 from dataiku.doctor.timeseries.utils import add_timeseries_identifiers_columns, prefix_custom_metric_name
 from dataiku.doctor.timeseries.utils import build_quantile_column_name
@@ -31,11 +31,12 @@ WORST_PREFIX = 'worst'
 
 
 class TimeseriesEvaluationHandler(object):
-    def __init__(self, core_params, preprocessing_params, modeling_params, metrics_params, clf, preprocessing_folder_context,
+    def __init__(self, core_params, preprocessing_params, modeling_params, resolved_modeling_params, metrics_params, clf, preprocessing_folder_context,
                  model_evaluation_store_folder_context, diagnostics_folder_context):
         self.core_params = core_params
         self.preprocessing_params = preprocessing_params
         self.modeling_params = modeling_params
+        self.resolved_modeling_params = resolved_modeling_params
         self.clf = clf
 
         self.resampling_params = self.preprocessing_params[doctor_constants.TIMESERIES_SAMPLING]
@@ -50,22 +51,25 @@ class TimeseriesEvaluationHandler(object):
         self.gap_size = evaluation_params[doctor_constants.GAP_SIZE]
 
         self.algorithm = TimeseriesForecastingAlgorithm.build(self.modeling_params["algorithm"])
-        self.min_timeseries_size = self.algorithm.get_min_size_for_scoring(self.modeling_params, self.prediction_length)
+        self.min_timeseries_size = self.algorithm.get_min_size_for_scoring(self.resolved_modeling_params,
+                                                                           self.preprocessing_params,
+                                                                           self.prediction_length)
 
         self.custom_metrics = metrics_params["customMetrics"]
 
         self.external_features = (
-            get_external_features(self.preprocessing_params) if self.algorithm.SUPPORTS_EXTERNAL_FEATURES else None
+            get_external_features(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)) if self.algorithm.SUPPORTS_EXTERNAL_FEATURES else None
         )
 
         context = DiagOnlyContext(diagnostics_folder_context)
         self.listener = ProgressListener(context=context)
 
         self.timeseries_preprocessing = TimeseriesPreprocessing(
-            preprocessing_folder_context, core_params, preprocessing_params, self.listener
+            preprocessing_folder_context, core_params, preprocessing_params, modeling_params, self.listener
         )
         self.has_model_evaluation_store = model_evaluation_store_folder_context is not None
         self.model_evaluation_store_folder_context = model_evaluation_store_folder_context
+        self.preprocessing_folder_context = preprocessing_folder_context
         if self.external_features:
             self.timeseries_preprocessing.load_resources()
 
@@ -87,7 +91,7 @@ class TimeseriesEvaluationHandler(object):
             (DataFrame, DataFrame): Tuple of a Dataframe containing the forecasts computed by using a rolling window for the past data, and the ground truth from the initial dataframe
                 and a DataFrame containing the metrics of each timeseries or aggregated over all timeseries.
         """
-        logger.info("Running evaluation recipe with params: {}".format(self.modeling_params))
+        logger.info("Running evaluation recipe with params: {}".format(self.resolved_modeling_params))
 
         with self.listener.push_step(step_constants.ProcessingStep.STEP_TIMESERIES_RESAMPLING):
             # Resample/preprocess full df. Resampling sorts the dataframe by time.
@@ -98,9 +102,14 @@ class TimeseriesEvaluationHandler(object):
                 self.core_params,
                 self.preprocessing_params,
                 self.external_features,
+                self.modeling_params.get("isShiftWindowsCompatible", False),
                 separate_external_features=False
             )
 
+            # Windowing is performed once and for all on the full dataframe
+            windows_list = get_windows_list(self.preprocessing_params) if self.modeling_params.get("isShiftWindowsCompatible", False) else []
+            resampled_df = add_rolling_windows_for_scoring(resampled_df, self.core_params, windows_list, self.preprocessing_params,  self.preprocessing_folder_context)
+
         if self.external_features:
             preprocess_on_full_df = self.algorithm.USE_GLUON_TS
 
@@ -233,6 +242,61 @@ class TimeseriesEvaluationHandler(object):
 
         return forecasts_df, metrics_df
 
+    def evaluate_without_scoring(self,
+                                 df_with_forecast,
+                                 quantiles,
+                                 output_metrics,
+                                 compute_metrics=False,
+                                 compute_per_timeseries_metrics=False):
+        """Compute metrics for an evaluation recipe with an already-made forecast.
+        Different from the evaluate function because the forecast computation is not done.
+
+        Args:
+            df_with_forecast (DataFrame): Input dataframe on which to evaluate. It should contain the forecast.
+            quantiles (list[float]): Quantiles used in forecast
+            output_metrics (list[str]): List of metrics to output
+            compute_metrics (bool, optional): Whether to compute metrics dataframe. Defaults to False.
+            compute_per_timeseries_metrics (bool, optional): Whether to compute per-timeseries metrics or global aggregated metrics. Defaults to False.
+
+        Returns:
+            (DataFrame): DataFrame containing the metrics of each timeseries or aggregated over all timeseries.
+        """
+        logger.info("Running evaluation recipe with params: {}".format(self.modeling_params))
+
+        model_scorer = TimeseriesModelScorer(
+            self.target_variable,
+            self.time_variable,
+            self.timeseries_identifier_columns,
+            self.prediction_length,
+            self.gap_size,
+            quantiles,
+            bool(self.timeseries_preprocessing.external_features),
+            self.frequency,
+            self.custom_metrics,
+            skip_scoring=True
+        )
+
+        per_timeseries_metrics, aggregated_metrics = model_scorer.score_without_historical_df(
+            df_with_forecast=df_with_forecast,
+            compute_aggregated_metrics=(self.has_model_evaluation_store or not compute_per_timeseries_metrics)
+        )
+
+        if self.has_model_evaluation_store:
+            score = { "perTimeseriesMetrics": per_timeseries_metrics, "aggregatedMetrics": aggregated_metrics}
+            _compute_and_append_worst_metrics(score, self.custom_metrics)
+            _save_score(self.timeseries_identifier_columns, model_scorer, score, self.model_evaluation_store_folder_context)
+            _save_forecasts(model_scorer, self.model_evaluation_store_folder_context)
+            _update_intrinsic_perf(model_scorer, self.model_evaluation_store_folder_context)
+
+        metrics_df = pd.DataFrame()
+        if compute_metrics:
+            if compute_per_timeseries_metrics:
+                metrics_df = _build_per_timeseries_metrics_df(per_timeseries_metrics, output_metrics)
+            else:
+                metrics_df = _build_aggregated_metrics_df(aggregated_metrics, output_metrics)
+
+        return metrics_df
+
 
 def _save_forecasts(model_scorer, folder_context):
     total_nb_timeseries = len(model_scorer.forecasts)
@@ -309,9 +373,10 @@ def _compute_and_append_worst_metrics(score, custom_metrics):
         for custom_metric in custom_metrics:
             metric_sign = 1 if custom_metric["greaterIsBetter"] else -1
             custom_metric_signs[prefix_custom_metric_name(custom_metric['name'])] = metric_sign
-
     for timeseries_identifier, timeseries_score in per_timeseries_metrics.items():
         for metric_key, metric_value in timeseries_score.items():
+            if metric_key == PER_FORECAST_DISTANCE_METRICS:
+                continue
             if metric_key in custom_metric_signs:
                 metric_sign = custom_metric_signs[metric_key]
             else:
