@@ -4,8 +4,9 @@ from typing import Optional, Type
 from dataiku.huggingface.types import ModelSettings
 from .model_sniffing_utils import _is_architecture
 from .model_sniffing_utils import _is_unquantized_expected_model_or_fine_tuned
-from .model_sniffing_utils import  _has_mistral_format
+from .model_sniffing_utils import _has_mistral_format
 from .model_params_loader import ModelParamsLoader
+from .model_params_loader import CompletionModelParamsLoader
 from .model_params_loader import Llama318BModelParamsLoader
 from .model_params_loader import Llama323BModelParamsLoader
 from .model_params_loader import Llama3211BVisionModelParamsLoader
@@ -17,12 +18,16 @@ from .model_params_loader import MistralFormatParamsLoader
 from .model_params_loader import Phi35VisionModelParamsLoader
 
 
-def get_model_params_loader(model_to_load: str, model_config: PretrainedConfig, model_settings: ModelSettings, with_image_input: bool, use_dss_model_cache: bool, lora_path: Optional[str]) -> ModelParamsLoader:
-    model_params_loader_class = _get_model_params_loader_class(model_to_load, model_config, use_dss_model_cache)
-    return model_params_loader_class(model_config, model_settings, with_image_input, lora_path)
+def get_model_params_loader_for_embedding(model_config: PretrainedConfig, model_settings: ModelSettings) -> ModelParamsLoader:
+    return ModelParamsLoader.build(model_config, model_settings)
 
 
-def _get_model_params_loader_class(model_to_load: str, model_config: PretrainedConfig, use_dss_model_cache: bool) -> Type[ModelParamsLoader]:
+def get_model_params_loader_for_completion(model_to_load: str, model_config: PretrainedConfig, model_settings: ModelSettings, with_image_input: bool, use_dss_model_cache: bool, lora_path: Optional[str]) -> ModelParamsLoader:
+    model_params_loader_class = _get_completion_model_params_loader_class(model_to_load, model_config, use_dss_model_cache)
+    return model_params_loader_class.build(model_config, model_settings, with_image_input=with_image_input, lora_path=lora_path)
+
+
+def _get_completion_model_params_loader_class(model_to_load: str, model_config: PretrainedConfig, use_dss_model_cache: bool) -> Type[CompletionModelParamsLoader]:
     if _is_unquantized_expected_model_or_fine_tuned(
         model_config, "Mistral 7B", "MistralForCausalLM", 32768, 32, 32, 4096, 14336
     ):
@@ -64,4 +69,4 @@ def _get_model_params_loader_class(model_to_load: str, model_config: PretrainedC
     if _has_mistral_format(model_to_load, use_dss_model_cache):
         return MistralFormatParamsLoader
 
-    return ModelParamsLoader
+    return CompletionModelParamsLoader
